# -*- coding: utf-8 -*-

__all__ = [
    'ValidationError'
]


###########
# CLASSES #
###########

class ValidationError(Exception):

    """
    Defines an exception thrown when inappropriate argument values are provided.
    """
